==> ssp-center-api-0.5.93sjq-20191029.101022-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/RspMaterialSpecificationDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.List;

/**
 * @author xuyenan
 * @createTime 2016/12/20
 */
public class RspMaterialSpecificationDto implements Serializable {

    private static final long                       serialVersionUID = 3169365972941062920L;

    private Long                                    id;                                     // 规格ID
    private String                                  title;                                  // 规格标题
    private String                                  description;                            // 规格描述
    private String                                  schematicImg;                           // 示意图
    private Integer                                 isDirect;                               // 是否定向
    private List<RspMaterialSpecificationItemDto>   itemDtoList;                            // 素材列表
    private List<RspMaterialSpecificationAssortDto> itemContentList;                        // 创意列表
    private Integer                                 isDelete;                               // 是否删除
    private Integer                                 isfixedData;                            // 固定数据(无法删除)

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getSchematicImg() {
        return schematicImg;
    }

    public void setSchematicImg(String schematicImg) {
        this.schematicImg = schematicImg;
    }

    public Integer getIsDirect() {
        return isDirect;
    }

    public void setIsDirect(Integer isDirect) {
        this.isDirect = isDirect;
    }

    public List<RspMaterialSpecificationItemDto> getItemDtoList() {
        return itemDtoList;
    }

    public void setItemDtoList(List<RspMaterialSpecificationItemDto> itemDtoList) {
        this.itemDtoList = itemDtoList;
    }

    public List<RspMaterialSpecificationAssortDto> getItemContentList() {
        return itemContentList;
    }

    public void setItemContentList(List<RspMaterialSpecificationAssortDto> itemContentList) {
        this.itemContentList = itemContentList;
    }

    public Integer getIsDelete() {
        return isDelete;
    }

    public void setIsDelete(Integer isDelete) {
        this.isDelete = isDelete;
    }

    public Integer getIsfixedData() {
        return isfixedData;
    }

    public void setIsfixedData(Integer isfixedData) {
        this.isfixedData = isfixedData;
    }
}

==> ssp-center-api-0.6.87-sjq4-20200325.021131-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/RspMaterialSpecificationDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.List;

/**
 * @author xuyenan
 * @createTime 2016/12/20
 */
public class RspMaterialSpecificationDto implements Serializable {

    private static final long                       serialVersionUID = 3169365972941062920L;

    private Long                                    id;                                     // 规格ID
    private String                                  title;                                  // 规格标题
    private String                                  description;                            // 规格描述
    private String                                  schematicImg;                           // 示意图
    private Integer                                 isDirect;                               // 是否定向
    private List<RspMaterialSpecificationItemDto>   itemDtoList;                            // 素材列表
    private List<RspMaterialSpecificationAssortDto> itemContentList;                        // 创意列表
    private Integer                                 isDelete;                               // 是否删除
    private Integer                                 isfixedData;                            // 固定数据(无法删除)

    private Integer sceneType; //投放场景

    private Integer sckType;  //素材类型

    private Integer isStandard; //是否标准规格

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getSchematicImg() {
        return schematicImg;
    }

    public void setSchematicImg(String schematicImg) {
        this.schematicImg = schematicImg;
    }

    public Integer getIsDirect() {
        return isDirect;
    }

    public void setIsDirect(Integer isDirect) {
        this.isDirect = isDirect;
    }

    public List<RspMaterialSpecificationItemDto> getItemDtoList() {
        return itemDtoList;
    }

    public void setItemDtoList(List<RspMaterialSpecificationItemDto> itemDtoList) {
        this.itemDtoList = itemDtoList;
    }

    public List<RspMaterialSpecificationAssortDto> getItemContentList() {
        return itemContentList;
    }

    public void setItemContentList(List<RspMaterialSpecificationAssortDto> itemContentList) {
        this.itemContentList = itemContentList;
    }

    public Integer getIsDelete() {
        return isDelete;
    }

    public void setIsDelete(Integer isDelete) {
        this.isDelete = isDelete;
    }

    public Integer getIsfixedData() {
        return isfixedData;
    }

    public void setIsfixedData(Integer isfixedData) {
        this.isfixedData = isfixedData;
    }

    public Integer getSceneType() {
        return sceneType;
    }

    public void setSceneType(Integer sceneType) {
        this.sceneType = sceneType;
    }

    public Integer getSckType() {
        return sckType;
    }

    public void setSckType(Integer sckType) {
        this.sckType = sckType;
    }

    public Integer getIsStandard() {
        return isStandard;
    }

    public void setIsStandard(Integer isStandard) {
        this.isStandard = isStandard;
    }
}
